package clarion.system;

/**
 * This class implements a generic stochastic object within CLARION.
 * It implements the InterfaceStochasticallySelectable interface.
 * <p>
 * <b>Usage:</b>
 * <p>
 * This class is used by the StochasticSelector class when you want to select over a group of objects that are not
 * necessarily an output chunk, which is what most often gets stochastically selected within CLARION.
 * <p>
 * Most often, this class is used by the ACS to stochastically decide which type (BL, RER, IRL, FR) to use for action
 * decision making.
 * @version 6.0.4
 * @author Nick Wilson
 */
public class GenericStochasticObject implements
		InterfaceStochasticallySelectable {
	
	/**The measure to use for stochastic selection.*/
	private double measure = 0;
	
	/**
	 * Initializes a generic stochastic object with the specified measure.
	 * @param m The measure to be used within the generic stochastic object for stochastic selection.
	 */
	public GenericStochasticObject (double m)
	{
		measure = m;
	}
	
	/**
	 * Sets the selection measure.
	 * @param m The measure to set.
	 */
	public void setFinalSelectionMeasure(double m)
	{
		measure = m;
	}
	
	/**
	 * Gets the selection measure.
	 * @return The selection measure.
	 */
	public double getFinalSelectionMeasure() {
		return measure;
	}
}
