package clarion.system;

/**
 * This interface is implemented by classes that handle feedback with a time stamp within CLARION.
 * It extends the InterfaceHandlesFeedback interface.
 * <p>
 * <b>Usage:</b>
 * <p>
 * Any class that implements this interface will be delivered feedback by CLARION when feedback
 * is received. In addition, the current time stamp will be provided to the class for internal purposes
 * not directly related to the handling of feedback. Most often, the time stamp is used to record the
 * exact time when a match occurred.
 * <p>
 * <b>Known classes implementing this interface:</b><br>
 * <ul>
 * <li>AbstractFixedRule</li>
 * <li>AbstractIRLRule</li>
 * <li>AbstractRule</li>
 * <li>RefineableRule</li>
 * </ul>
 * @version 6.0.4
 * @author Nick Wilson
 */
public interface InterfaceHandlesFeedbackWithTime extends InterfaceHandlesFeedback{
	
	/**
	 * Checks to see if a match criterion has been obtained. This match criterion is
	 * used separately from the match statistics. Depending on how it is implemented,
	 * it can be used either for matching inputs or for deciding if extraction should occur
	 * (along with other possibilities).
	 * <p>
	 * The time stamp is not necessarily used for criterion matching, but instead to provide
	 * a time stamp for remember the exact time that the criterion was matched.
	 * @param TimeStamp The current time stamp.
	 * @return True if the match criterion has been met, otherwise false.
	 */
	boolean checkMatchCriterion(long TimeStamp);
}
